@@ -1,7 +1,7 @@
 package App::CompleteCLIs;
 
-our $DATE = '2015-09-18'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-10-15'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,14 +22,15 @@ App::CompleteCLIs - CLI wrappers for complete_*() functions
 
 =head1 VERSION
 
-This document describes version 0.06 of App::CompleteCLIs (from Perl distribution App-CompleteCLIs), released on 2015-09-18.
+This document describes version 0.07 of App::CompleteCLIs (from Perl distribution App-CompleteCLIs), released on 2016-10-15.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
 This distribution comes with the following CLI's from the various C<Complete::*>
-modules:
+modules. They are meant for convenient testing of the various C<complete_*>
+functions on the command-line.
 
 =over
 
@@ -57,6 +58,8 @@ modules:
 
 =item * L<complete-int>
 
+=item * L<complete-locale>
+
 =item * L<complete-manpage>
 
 =item * L<complete-module>
@@ -85,12 +88,6 @@ modules:
 
 =back
 
-=head1 SEE ALSO
-
-L<Complete>
-
-C<Complete::*> modules
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-CompleteCLIs>.
@@ -107,13 +104,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Complete>
+
+C<Complete::*> modules
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
